@@ -37,19 +37,19 @@ int xdl_set_allocator(memallocator_t const *malt) {
 
 void *xdl_malloc(unsigned int size) {
 
-	return xmalt.malloc ? xmalt.malloc(size): NULL;
+	return xmalt.malloc ? xmalt.malloc(xmalt.priv, size): NULL;
 }
 
 
 void xdl_free(void *ptr) {
 
 	if (xmalt.free)
-		xmalt.free(ptr);
+		xmalt.free(xmalt.priv, ptr);
 }
 
 
 void *xdl_realloc(void *ptr, unsigned int size) {
 
-	return xmalt.realloc ? xmalt.realloc(ptr, size): NULL;
+	return xmalt.realloc ? xmalt.realloc(xmalt.priv, ptr, size): NULL;
 }
 
